@@ -15,7 +15,7 @@ import re
 
 GB = 1024. * 1024. * 1024.
 MB = 1024. * 1024.
-_object_id = "CRED_OBJECT_ID"
+_object_id = "OBJECT_ID"
 
 def pytest_addoption(parser):
     """
@@ -79,7 +79,7 @@ def env(env_file):
     load_dotenv(env_file)
     prefix = "CRED_"
     my_pattern = re.compile(r'{prefix}\w+'.format(prefix=prefix))
-    my_env_variables = {key.replace(prefix, ''): val for key, val in os.environ.items() if my_pattern.match(key)}
+    my_env_variables = {key.replace(prefix, ''): val.lower() for key, val in os.environ.items() if my_pattern.match(key)}
 
     return my_env_variables
 
